Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(16)

Unified Diff: pkg/analysis_services/lib/completion/completion_computer.dart

Issue 465843002: respect show/hide combinators when generating suggestions (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: address comments Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/analysis_services/lib/src/completion/dart_completion_manager.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analysis_services/lib/completion/completion_computer.dart
diff --git a/pkg/analysis_services/lib/completion/completion_computer.dart b/pkg/analysis_services/lib/completion/completion_computer.dart
index 0962cdfb57fc92073fc9cb729f4573a91f520c12..6d06232790cf6925e7b4157308284d4117a00692 100644
--- a/pkg/analysis_services/lib/completion/completion_computer.dart
+++ b/pkg/analysis_services/lib/completion/completion_computer.dart
@@ -23,20 +23,24 @@ abstract class CompletionComputer {
SearchEngine searchEngine;
/**
* Computes the initial set of [CompletionSuggestion]s based on information
* already cached in the analysis context. This method should execute
* quickly and not block waiting for any analysis.
* Returns `true` if the computer's work is complete
* or `false` if [computeFull] should be called to complete the work.
*/
- bool computeFast(CompilationUnit unit,
+ bool computeFast(CompilationUnit unit, AstNode node,
List<CompletionSuggestion> suggestions);
/**
- * Computes [CompletionSuggestion]s for the specified position in the source.
+ * Computes the complete set of [CompletionSuggestion]s based on
+ * the resolved compilation [unit] and the resolved AST [node] in which the
+ * completion occurred.
* Returns `true` if the receiver modified the list of suggestions.
*/
- Future<bool> computeFull(CompilationUnit unit,
+ Future<bool> computeFull(CompilationUnit unit, AstNode node,
List<CompletionSuggestion> suggestions);
}
« no previous file with comments | « no previous file | pkg/analysis_services/lib/src/completion/dart_completion_manager.dart » ('j') | no next file with comments »
@@ -23,20 +23,24 @@ abstract class CompletionComputer {
SearchEngine searchEngine;
/**
- * Computes the initial set of [CompletionSuggestion]s based on information
- * already cached in the analysis context. This method should execute
- * quickly and not block waiting for any analysis.
+ * Computes the initial set of [CompletionSuggestion]s based on
+ * the compilation [unit], the AST [node] in which the completion occurred,
+ * and information already cached in the analysis context.
+ * The supplied [unit] and [node] may not be resolved.
+ * This method should execute quickly and not block waiting for any analysis.
* Returns `true` if the computer's work is complete
* or `false` if [computeFull] should be called to complete the work.

Powered by Google App Engine
This is Rietveld 408576698